Storage class for the result of a bootstrap particle filter analysis. The class holds the model with a sampled trajectory attached, the number of particles used, the estimated log-likelihood, and the effective sample size (ESS) at each time-point.
Slots
modelA
SimInf_modelobject with one complete sampled trajectory attached. At the end of the filtering, a single particle is drawn from the ensemble at the final time-point, and its full state evolution across all time-points is reconstructed.n_particlesAn integer with the number of particles that was used at each time-step.
loglikThe estimated log-likelihood.
essA numeric vector with the effective sample size (ESS) at each time-point. The effective sample size is computed as $$\left(\sum_{i=1}^N\!(w_{t}^{i})^2\right)^{-1},$$ where \(w_{t}^{i}\) is the normalized weight of particle \(i\) at time \(t\).
See also
pfilter for running a bootstrap particle
filter and creating objects of this class,
logLik for
extracting the log-likelihood,
trajectory
for extracting the filtered trajectory,
prevalence
for computing prevalence from the filtered trajectory,
SimInf_model for the underlying model
class.