Learn R Programming

SimInf (version 8.4.0)

abc_accept: Return result for ABC whether the particles match the data

Description

Return result for ABC whether the particles match the data

Usage

abc_accept(accept, epsilon)

Arguments

accept

A logical vector with one value for each particle in the simulated model.

epsilon

A numeric vector with the tolerance for the generation.

Value

list(accept = accept, epsilon = epsilon)