Learn R Programming

SimInf (version 11.1.0)

show,SimInf_pfilter-method: Brief summary of a SimInf_pfilter object

Description

Display a brief summary of a bootstrap particle filter analysis, including the number of particles used and the estimated log-likelihood.

Usage

# S4 method for SimInf_pfilter
show(object)

Value

The object, returned invisibly.

Arguments

object

The SimInf_pfilter object to display.

See Also

pfilter for running a particle filter, logLik for extracting the log-likelihood, SimInf_pfilter for the class definition.