powered by
SimInf_pfilter
Display a brief summary of a bootstrap particle filter analysis, including the number of particles used and the estimated log-likelihood.
# S4 method for SimInf_pfilter show(object)
The object, returned invisibly.
object
The SimInf_pfilter object to display.
pfilter for running a particle filter, logLik for extracting the log-likelihood, SimInf_pfilter for the class definition.
pfilter
logLik