Skip to contents

Display a brief summary of a bootstrap particle filter analysis, including the number of particles used and the estimated log-likelihood.

Usage

# S4 method for class 'SimInf_pfilter'
show(object)

Arguments

object

The SimInf_pfilter object to display.

Value

The object, returned invisibly.

See also

pfilter for running a particle filter, logLik for extracting the log-likelihood, SimInf_pfilter for the class definition.