SimInf_abc objectDisplay a detailed summary of an approximate Bayesian computation (ABC) analysis, including the number of particles per generation, the number of generations, and—for each generation—the acceptance rate, effective sample size (ESS), and summary statistics (minimum, first quartile, median, mean, third quartile, and maximum) for each parameter in the posterior distribution.
# S4 method for SimInf_abc
summary(object, ...)NULL, returned invisibly.
The SimInf_abc object to
summarize.
Additional arguments affecting the summary produced. Currently ignored.
Compared to show, the
summary additionally displays posterior statistics for all
generations, not just the final one.
abc for running an ABC analysis,
continue_abc for continuing an existing ABC
chain, SimInf_abc for the class
definition, show for a
brief summary.