## Create an 'SIR' model with 1600 cattle herds (nodes) and
## scheduled events for the population of nodes with births,
## deaths and between-node movements of individuals. Define
## 'tspan' to record the state of the system at daily time
## points over 4*365 days.
model <- SIR(
u0 = u0_SIR(),
tspan = 1:(4 * 365),
events = events_SIR(),
beta = 0.16,
gamma = 0.077
)
## Detailed summary of the events
summary(events(model))
Run the code above in your browser using DataLab