Skip to contents

Display a detailed summary of an approximate Bayesian computation (ABC) analysis, including the number of particles per generation, the number of generations, and—for each generation—the acceptance rate, effective sample size (ESS), and summary statistics (minimum, first quartile, median, mean, third quartile, and maximum) for each parameter in the posterior distribution.

Usage

# S4 method for class 'SimInf_abc'
summary(object, ...)

Arguments

object

The SimInf_abc object to summarize.

...

Additional arguments affecting the summary produced. Currently ignored.

Value

NULL, returned invisibly.

Details

Compared to show, the summary additionally displays posterior statistics for all generations, not just the final one.

See also

abc for running an ABC analysis, continue_abc for continuing an existing ABC chain, SimInf_abc for the class definition, show for a brief summary.