Skip to contents

Display a summary of a SimInf_individual_events object, including the number of unique individuals, the total number of event records, and the number of events by event type (exit, enter, internal transfer, and external transfer).

Usage

# S4 method for class 'SimInf_individual_events'
summary(object, ...)

Arguments

object

The SimInf_individual_events object to summarize.

...

Additional arguments affecting the summary produced. Currently ignored.

Value

NULL, returned invisibly.

See also

individual_events for creating SimInf_individual_events objects, SimInf_individual_events for the class definition, SimInf_events for the node-level event class, show for a brief summary.