Class to handle the SIS model. This class inherits from
SimInf_model, meaning that SIS
objects are fully compatible with all generic functions defined
for SimInf_model, such as run,
plot, trajectory,
and prevalence.
Details
The SIS model is a compartmental model for infectious diseases where individuals do not gain permanent immunity after recovery. Instead, they return to the susceptible state. It divides the population into two states: Susceptible and Infected.
The model is defined by two state transitions: $$S \stackrel{\beta S I / N}{\longrightarrow} I$$ $$I \stackrel{\gamma I}{\longrightarrow} S$$
where \(\beta\) is the transmission rate, \(\gamma\) is the recovery rate, and \(N = S + I\) is the total population size in each node. Here, \(S\) and \(I\) represent the number of susceptible and infected individuals in that specific node.
See also
SIS for creating an SIS model object,
SimInf_model for the parent class definition,
SIR for a model with permanent immunity, and
SEIR for a model including a latent period.