Class SimInf_pmcmc
Slots
modelThe
SimInf_modelobject to estimate parameters in.priorsA
data.framedefining the prior distributions for the parameters. It contains four columns:parameter: The name of the parameter in the model.distribution: The prior distribution type. Valid values are"gamma","lognormal","normal", or"uniform".p1: The first hyperparameter:"gamma": shape"lognormal": meanlog (mean on the log scale)"normal": mean"uniform": lower bound
p2: The second hyperparameter:"gamma": rate"lognormal": sdlog (standard deviation on the log scale)"normal": sd (standard deviation)"uniform": upper bound
targetCharacter vector (
"gdata"or"ldata") that determines if the ABC-SMC method estimates parameters inmodel@gdata(global data) or inmodel@ldata(local data).parsAn integer vector with the indices of the parameters in
targetthat are being estimated.n_particlesAn integer with the number of particles (> 1) to use in the bootstrap particle filter.
dataA
data.frameholding the time series data for the observation process.chainA matrix where each row contains
logPost,logLik,logPrior,accept, and theparametersfor each iteration.covmatA named numeric
(npars x npars)matrix with covariances to use as initial proposal matrix.adaptmixA numeric scalar specifying the mixing proportion for the adaptive proposal distribution.
adaptiveAn integer specifying when to start the adaptive update of the proposal distribution (iteration number).
See also
pmcmc for the main PMCMC function,
continue_pmcmc for continuing an existing PMCMC
run, and abc for ABC-SMC parameter estimation.