Run more generations of ABC SMC
continue_abc(
object,
tolerance = NULL,
data = NULL,
verbose = FALSE,
post_gen = NULL
)# S4 method for SimInf_abc
continue_abc(
object,
tolerance = NULL,
data = NULL,
verbose = FALSE,
post_gen = NULL
)
A SimInf_abc object.
The SimInf_abc object to continue from.
A numeric matrix (number of summary statistics \(\times\) number of generations) where each column contains the tolerances for a generation and each row contains a sequence of gradually decreasing tolerances. Can also be a numeric vector if there is only one summary statistic. The tolerance determines the number of generations of ABC-SMC to run.
Optional data to be passed to the
SimInf_abc@fn function. Default is NULL.
prints diagnostic messages when TRUE.
Default is FALSE.
An optional function that, if non-NULL, is applied
after each completed generation. The function must accept one
argument of type SimInf_abc with the current state of
the fitting process. This function can be useful to, for
example, save and inspect intermediate results.