The principal branch of the Lambert W function, which solves \(W e^W = x\). Defined for \(x >= -1/e\), with output in the range \([-1, \infty)\). The value is calculated using the GNU Scientific Library (GSL).
The principal branch of the Lambert W function, which solves \(W e^W = x\). Defined for \(x >= -1/e\), with output in the range \([-1, \infty)\). The value is calculated using the GNU Scientific Library (GSL).