The principal branch of the Lambert W function, which solves
\(W e^W = x\). Defined for \(x >= -1/e\), with
output in the range \([-1, \infty)\). The value is
calculated using the GNU Scientific Library (GSL).
Usage
lambertW0(x)
Value
A numeric vector of the same length as x containing
the principal branch of the Lambert W function evaluated at
each element.
Arguments
x
A numeric vector of values.
References
GNU Scientific Library <https://www.gnu.org/software/gsl/>