Calculate the proportion of cases (specified on the left-hand side of the formula) relative to the population at risk (specified on the right-hand side) at different aggregation levels. The function supports three levels of calculation:
Level 1 (Population Prevalence): The proportion of cases in the total population at risk across all nodes.
Level 2 (Node Prevalence): The proportion of nodes that contain at least one case, considering only nodes where the population at risk is greater than zero.
Level 3 (Within-Node Prevalence): The proportion of cases relative to the population at risk calculated separately for each node.
Arguments
- model
The
modelwith trajectory data to calculate the prevalence from.- formula
A formula that specifies the compartments that define the cases with a disease or that have a specific characteristic (numerator), and the compartments that define the entire population of interest (denominator). The left-hand-side of the formula defines the cases, and the right-hand-side defines the population, for example,
I~S+I+Rin a ‘SIR’ model (see ‘Examples’). The.(dot) is expanded to all compartments, for example,I~.is expanded toI~S+I+Rin a ‘SIR’ model (see ‘Examples’). The formula can also contain a condition (indicated by|) for each node and time step to further control the population to include in the calculation, for example,I ~ . | R == 0to calculate the prevalence when the recovered is zero in a ‘SIR’ model. The condition must evaluate toTRUEorFALSEin each node and time step. Please note, if the denominator is zero, the prevalence isNaN. Additionally, whenlevel=3(within-node prevalence) and the formula contains a condition that evaluates toFALSE, the prevalence is alsoNaN.- level
The level at which the prevalence is calculated at each time point in
tspan. 1 (population prevalence): calculates the proportion of the individuals (cases) in the population. 2 (node prevalence): calculates the proportion of nodes with at least one case. 3 (within-node prevalence): calculates the proportion of cases within each node. Default is1.- index
indices specifying the subset of nodes to include when extracting data. Default (
index = NULL) is to extract data from all nodes.- ...
Additional arguments, see
prevalence,SimInf_model-method