## For reproducibility, specify the number of threads to use.
set_num_threads(1)
## Create an 'SIR' model with 10 nodes.
model <- SIR(
u0 = data.frame(
S = rep(99, 10),
I = rep(1, 10),
R = rep(0, 10)
),
tspan = 1:100,
beta = 0.16,
gamma = 0.077
)
## Run the model with a fixed seed for reproducibility.
result <- run(model, seed = 22)
## Plot the distribution of susceptible, infected and recovered
## individuals.
plot(result)
Run the code above in your browser using DataLab