Display a summary of an approximate Bayesian computation (ABC) analysis, including the number of particles per generation, the number of generations, and—for the final generation—the acceptance rate, effective sample size (ESS), and summary statistics (minimum, first quartile, median, mean, third quartile, and maximum) for each parameter in the posterior distribution.
Arguments
- object
The
SimInf_abcobject to display.
See also
abc for running an ABC analysis,
continue_abc for continuing an existing ABC
chain, SimInf_abc for the class
definition.