Display a brief summary of a bootstrap particle filter analysis, including the number of particles used and the estimated log-likelihood.
Arguments
- object
The
SimInf_pfilterobject to display.
See also
pfilter for running a particle filter,
logLik for extracting the log-likelihood,
SimInf_pfilter for the class definition.