Display a detailed summary of a bootstrap particle filter analysis, including the number of particles, log-likelihood estimate, and model characteristics (model name, number of nodes, scheduled events, transitions, global data, local data, continuous state variables, and compartments).
Usage
# S4 method for class 'SimInf_pfilter'
summary(object, ...)Arguments
- object
The
SimInf_pfilterobject to summarize.- ...
Additional arguments affecting the summary produced. Currently ignored.
Details
Compared to show, the
summary additionally displays full model characteristics from the
underlying SimInf_model object.
See also
pfilter for running a particle filter,
logLik for extracting the log-likelihood,
SimInf_pfilter for the class definition,
SimInf_model for the model class embedded
in the filter, show
for a brief summary.